import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { WorkMailClientResolvedConfig } from "../WorkMailClient";
/**
 * @internal
 */
export interface WorkMailHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface WorkMailHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<WorkMailClientResolvedConfig, HandlerExecutionContext, WorkMailHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultWorkMailHttpAuthSchemeParametersProvider: (config: WorkMailClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<WorkMailHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface WorkMailHttpAuthSchemeProvider extends HttpAuthSchemeProvider<WorkMailHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultWorkMailHttpAuthSchemeProvider: WorkMailHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: WorkMailHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: WorkMailHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
