import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { TestAvailabilityConfigurationRequest, TestAvailabilityConfigurationResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, WorkMailClientResolvedConfig } from "../WorkMailClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link TestAvailabilityConfigurationCommand}.
 */
export interface TestAvailabilityConfigurationCommandInput extends TestAvailabilityConfigurationRequest {
}
/**
 * @public
 *
 * The output of {@link TestAvailabilityConfigurationCommand}.
 */
export interface TestAvailabilityConfigurationCommandOutput extends TestAvailabilityConfigurationResponse, __MetadataBearer {
}
declare const TestAvailabilityConfigurationCommand_base: {
    new (input: TestAvailabilityConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<TestAvailabilityConfigurationCommandInput, TestAvailabilityConfigurationCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: TestAvailabilityConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<TestAvailabilityConfigurationCommandInput, TestAvailabilityConfigurationCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Performs a test on an availability provider to ensure that access is allowed. For EWS, it verifies the provided credentials can be used to successfully log in. For Lambda, it verifies that the Lambda function can be invoked and that the resource access
 *          policy was configured to deny anonymous access. An anonymous invocation is one done without providing either a <code>SourceArn</code> or <code>SourceAccount</code> header.</p>
 *          <note>
 *             <p>The request must contain either one provider definition (<code>EwsProvider</code> or
 *                <code>LambdaProvider</code>) or the <code>DomainName</code> parameter. If the
 *                <code>DomainName</code> parameter is provided, the configuration stored under the
 *                <code>DomainName</code> will be tested.</p>
 *          </note>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { WorkMailClient, TestAvailabilityConfigurationCommand } from "@aws-sdk/client-workmail"; // ES Modules import
 * // const { WorkMailClient, TestAvailabilityConfigurationCommand } = require("@aws-sdk/client-workmail"); // CommonJS import
 * const client = new WorkMailClient(config);
 * const input = { // TestAvailabilityConfigurationRequest
 *   OrganizationId: "STRING_VALUE", // required
 *   DomainName: "STRING_VALUE",
 *   EwsProvider: { // EwsAvailabilityProvider
 *     EwsEndpoint: "STRING_VALUE", // required
 *     EwsUsername: "STRING_VALUE", // required
 *     EwsPassword: "STRING_VALUE", // required
 *   },
 *   LambdaProvider: { // LambdaAvailabilityProvider
 *     LambdaArn: "STRING_VALUE", // required
 *   },
 * };
 * const command = new TestAvailabilityConfigurationCommand(input);
 * const response = await client.send(command);
 * // { // TestAvailabilityConfigurationResponse
 * //   TestPassed: true || false,
 * //   FailureReason: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param TestAvailabilityConfigurationCommandInput - {@link TestAvailabilityConfigurationCommandInput}
 * @returns {@link TestAvailabilityConfigurationCommandOutput}
 * @see {@link TestAvailabilityConfigurationCommandInput} for command's `input` shape.
 * @see {@link TestAvailabilityConfigurationCommandOutput} for command's `response` shape.
 * @see {@link WorkMailClientResolvedConfig | config} for WorkMailClient's `config` shape.
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the input parameters don't match the service's restrictions.</p>
 *
 * @throws {@link OrganizationNotFoundException} (client fault)
 *  <p>An operation received a valid organization identifier that either doesn't belong or
 *          exist in the system.</p>
 *
 * @throws {@link OrganizationStateException} (client fault)
 *  <p>The organization must have a valid state to perform certain
 *          operations on the organization or its members.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The resource cannot be found.</p>
 *
 * @throws {@link WorkMailServiceException}
 * <p>Base exception class for all service exceptions from WorkMail service.</p>
 *
 * @public
 */
export declare class TestAvailabilityConfigurationCommand extends TestAvailabilityConfigurationCommand_base {
}
